# Boost.Assert

The Boost.Assert library, part of the collection of [Boost C++ Libraries](http://github.com/boostorg),
provides several configurable diagnostic macros similar in behavior and purpose to the standard macro
`assert` from `<cassert>`.

## Documentation

See the documentation of [BOOST_ASSERT](doc/assert.adoc) and
[BOOST_CURRENT_FUNCTION](doc/current_function.adoc) for more information.

## License

Distributed under the [Boost Software License, Version 1.0](http://boost.org/LICENSE_1_0.txt).
